aboutsummaryrefslogtreecommitdiff
path: root/include/curl
diff options
context:
space:
mode:
authorSteve Holme <steve_holme@hotmail.com>2013-11-12 19:01:04 +0000
committerSteve Holme <steve_holme@hotmail.com>2013-11-12 19:08:55 +0000
commitf2584627c8314b5954645ed4e05f48868928bd87 (patch)
tree23d3eb15bab917bee8ade395c83d08a44f90c32c /include/curl
parent6901861fc97f0b3cb9ee8590c449ab6aa2fe0500 (diff)
curl_easy_setopt: Added the ability to set the login options separately
Rather than set the authentication options as part of the login details specified in the URL, or via the older CURLOPT_USERPWD option, added a new libcurl option to allow the login options to be set separately.
Diffstat (limited to 'include/curl')
-rw-r--r--include/curl/curl.h7
-rw-r--r--include/curl/typecheck-gcc.h1
2 files changed, 6 insertions, 2 deletions
diff --git a/include/curl/typecheck-gcc.h b/include/curl/typecheck-gcc.h
index e8f1dff9a..7feccf347 100644
--- a/include/curl/typecheck-gcc.h
+++ b/include/curl/typecheck-gcc.h
@@ -269,6 +269,7 @@ _CURL_WARNING(_curl_easy_getinfo_err_curl_slist,
(option) == CURLOPT_DNS_INTERFACE || \
(option) == CURLOPT_DNS_LOCAL_IP4 || \
(option) == CURLOPT_DNS_LOCAL_IP6 || \
+ (option) == CURLOPT_OPTIONS || \
0)
/* evaluates to true if option takes a curl_write_callback argument */
diff --git a/include/curl/curl.h b/include/curl/curl.h
index e3c6bf279..14ff7c756 100644
--- a/include/curl/curl.h
+++ b/include/curl/curl.h
@@ -827,10 +827,10 @@ typedef enum {
/* Name of proxy to use. */
CINIT(PROXY, OBJECTPOINT, 4),
/* "name:password" to use when fetching. */
CINIT(USERPWD, OBJECTPOINT, 5),
- /* "name:password" to use with proxy. */
+ /* "user:password" to use with proxy. */
CINIT(PROXYUSERPWD, OBJECTPOINT, 6),
/* Range to get, specified as an ASCII string. */
@@ -1569,6 +1569,9 @@ typedef enum {
* Only supported by the c-ares DNS backend */
CINIT(DNS_LOCAL_IP6, OBJECTPOINT, 223),
+ /* Set authentication options directly */
+ CINIT(OPTIONS, OBJECTPOINT, 224),
+
CURLOPT_LASTENTRY /* the last unused */
} CURLoption;
@@ -827,10 +827,10 @@ typedef enum {
/* Name of proxy to use. */
CINIT(PROXY, OBJECTPOINT, 4),
- /* "name:password" to use when fetching. */
+ /* "user:password;options" to use when fetching. */
CINIT(USERPWD, OBJECTPOINT, 5),